@@ -160,7 +160,7 @@ class CloudFrontToApiGateway(
             insert_http_security_headers=insert_http_security_headers,
         )
 
-        jsii.create(CloudFrontToApiGateway, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
